==> killbill-api-0.53.17-sources.jar: org/killbill/billing/util/nodes/DefaultNodeCommandMetadata.java <==
/*
 * Copyright 2010-2013 Ning, Inc.
 * Copyright 2015-2019 Groupon, Inc
 * Copyright 2015-2019 The Billing Project, LLC
 *
 * The Billing Project licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package org.killbill.billing.util.nodes;

import java.util.List;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

public class DefaultNodeCommandMetadata implements NodeCommandMetadata {

    private List<NodeCommandProperty> properties;

    // For Jackson
    public DefaultNodeCommandMetadata() {
    }

    @JsonCreator
    public DefaultNodeCommandMetadata(@JsonProperty("properties") final List<NodeCommandProperty> properties) {
        this.properties = properties;
    }

    @Override
    public List<NodeCommandProperty> getProperties() {
        return properties;
    }

    @Override
    public String toString() {
        final StringBuffer sb = new StringBuffer("DefaultNodeCommandMetadata{");
        sb.append("properties=").append(properties);
        sb.append('}');
        return sb.toString();
    }
}

==> killbill-api-0.54.0-sources.jar: org/killbill/billing/util/nodes/DefaultNodeCommandMetadata.java <==
/*
 * Copyright 2010-2013 Ning, Inc.
 * Copyright 2015-2019 Groupon, Inc
 * Copyright 2015-2019 The Billing Project, LLC
 *
 * The Billing Project licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package org.killbill.billing.util.nodes;

import java.util.List;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

public class DefaultNodeCommandMetadata implements NodeCommandMetadata {

    private List<NodeCommandProperty> properties;

    // For Jackson
    public DefaultNodeCommandMetadata() {
    }

    @JsonCreator
    public DefaultNodeCommandMetadata(@JsonProperty("properties") final List<NodeCommandProperty> properties) {
        this.properties = List.copyOf(properties);
    }

    @Override
    public List<NodeCommandProperty> getProperties() {
        return List.copyOf(properties);
    }

    @Override
    public String toString() {
        final StringBuffer sb = new StringBuffer("DefaultNodeCommandMetadata{");
        sb.append("properties=").append(properties);
        sb.append('}');
        return sb.toString();
    }
}
